# frozen_string_literal: true

# Redmine - project management software
# Copyright (C) 2006-2023  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require_relative '../../test_helper'

class RoutingActivitiesTest < Redmine::RoutingTest

  def test_activity
    should_route 'GET /activity' => 'activities#index'
    should_route 'GET /activity.atom' => 'activities#index', :format => 'atom'
  end

  def test_project_activity
    should_route 'GET /projects/33/activity' => 'activities#index', :id => '33'
    should_route 'GET /projects/33/activity.atom' => 'activities#index', :id => '33', :format => 'atom'
  end
end
